Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChatResponse ¶
type ChatResponse struct {
Output string `json:"output"`
ToolCalls []ToolCallLog `json:"tool_calls"`
RAGUsed bool `json:"rag_used"`
CacheHit bool `json:"cache_hit"`
Latency int64 `json:"latency_ms"`
TokensUsed int `json:"tokens_used"`
Error *string `json:"error,omitempty"`
}
ChatResponse is used here for simplicity as the cache package handles the storage of the final engine output
type KnowledgeChunk ¶
type KnowledgeChunk struct {
ID string `json:"id"`
Content string `json:"content"`
Category string `json:"category"`
Role string `json:"role,omitempty"`
Files []string `json:"files,omitempty"`
FilesPath string `json:"files_path,omitempty"`
Source string `json:"source,omitempty"`
Score float32 `json:"score,omitempty"`
Embedding []float32 `json:"-"`
}
KnowledgeChunk represents a piece of information from the knowledge base.
Click to show internal directories.
Click to hide internal directories.